@@ -22,6 +22,7 @@ tf = pytest.importorskip("tensorflow")
 tr = pytest.importorskip("transformers4rec.tf")
 
 
+@pytest.mark.xfail
 @pytest.mark.parametrize("replacement_prob", [0.1, 0.3, 0.5, 0.7])
 def test_stochastic_swap_noise(replacement_prob):
     NUM_SEQS = 100
@@ -52,6 +53,7 @@ def test_stochastic_swap_noise(replacement_prob):
         assert replacement_rate == pytest.approx(replacement_prob, abs=0.15)
 
 
+@pytest.mark.xfail
 @pytest.mark.parametrize("replacement_prob", [0.1, 0.3, 0.5, 0.7])
 def test_stochastic_swap_noise_disable_on_eval(replacement_prob):
     NUM_SEQS = 100
@@ -78,6 +80,7 @@ def test_stochastic_swap_noise_disable_on_eval(replacement_prob):
         assert tf.reduce_all(replaced_mask).numpy()
 
 
+@pytest.mark.xfail
 @pytest.mark.parametrize("replacement_prob", [0.1, 0.3, 0.5, 0.7])
 def test_stochastic_swap_noise_with_tabular_features(
     yoochoose_schema, tf_yoochoose_like, replacement_prob
@@ -92,7 +95,7 @@ def test_stochastic_swap_noise_with_tabular_features(
         pad_token=PAD_TOKEN, replacement_prob=replacement_prob, schema=yoochoose_schema
     )
 
-    out_features_ssn = tab_module(inputs, pre=ssn)
+    out_features_ssn = tab_module(inputs, pre=ssn, training=True)
 
     for fname in out_features_ssn:
         replaced_mask = out_features[fname] != out_features_ssn[fname]
@@ -106,6 +109,7 @@ def test_stochastic_swap_noise_with_tabular_features(
         assert replacement_rate == pytest.approx(replacement_prob, abs=0.15)
 
 
+@pytest.mark.xfail
 def test_stochastic_swap_noise_raise_exception_not_2d_item_id():
 
     s = schema.Schema(
