@@ -18,6 +18,11 @@ import transformers
 
 from merlin_standard_lib import Registry
 
+try:
+    import tensorflow as tf
+except ImportError:
+    tf = None
+
 transformer_registry: Registry = Registry("transformers")
 
 
@@ -58,40 +63,42 @@ class T4RecConfig:
             loss_reduction=loss_reduction,
         ).to_model(**kwargs)
 
-    def to_tf_model(
-        self,
-        input_features,
-        *prediction_task,
-        task_blocks=None,
-        task_weights=None,
-        loss_reduction="mean",
-        **kwargs
-    ):
-        from .. import tf as tf4rec
+    if tf:
 
-        if not isinstance(input_features, tf4rec.TabularSequenceFeatures):
-            raise ValueError("`input_features` must an instance of SequentialTabularFeatures")
-        if not all(isinstance(t, tf4rec.PredictionTask) for t in prediction_task):
-            raise ValueError(
-                "`task` is of the wrong type, please provide one or multiple "
-                "instance(s) of PredictionTask"
+        def to_tf_model(
+            self,
+            input_features,
+            *prediction_task,
+            task_blocks=None,
+            task_weights=None,
+            loss_reduction=tf.reduce_mean,
+            **kwargs
+        ):
+            from .. import tf as tf4rec
+
+            if not isinstance(input_features, tf4rec.TabularSequenceFeatures):
+                raise ValueError("`input_features` must an instance of SequentialTabularFeatures")
+            if not all(isinstance(t, tf4rec.PredictionTask) for t in prediction_task):
+                raise ValueError(
+                    "`task` is of the wrong type, please provide one or multiple "
+                    "instance(s) of PredictionTask"
+                )
+
+            body = tf4rec.SequentialBlock(
+                [input_features, tf4rec.TransformerBlock(self, masking=input_features.masking)]
             )
 
-        body = tf4rec.SequentialBlock(
-            [input_features, tf4rec.TransformerBlock(self, masking=input_features.masking)]
-        )
-
-        return tf4rec.Model(
-            tf4rec.Head(
-                body,
-                *prediction_task,
-                task_blocks=task_blocks,
-                task_weights=task_weights,
-                loss_reduction=loss_reduction,
-                inputs=input_features,
-            ),
-            **kwargs,
-        )
+            return tf4rec.Model(
+                tf4rec.Head(
+                    body,
+                    *prediction_task,
+                    task_blocks=task_blocks,
+                    task_weights=task_weights,
+                    loss_reduction=loss_reduction,
+                    inputs=input_features,
+                ),
+                **kwargs,
+            )
 
     def to_huggingface_tf_model(self):
         model_cls = transformers.TF_MODEL_MAPPING[self.transformers_config_cls]
@@ -308,6 +315,7 @@ class XLNetConfig(T4RecConfig, transformers.XLNetConfig):
         dropout=0.3,
         pad_token=0,
         log_attention_weights=False,
+        mem_len=1,
         **kwargs
     ):
         return cls(
@@ -323,6 +331,7 @@ class XLNetConfig(T4RecConfig, transformers.XLNetConfig):
             pad_token_id=pad_token,
             output_attentions=log_attention_weights,
             vocab_size=1,
+            mem_len=mem_len,
             **kwargs,
         )
 
